From 5acf3c7cdfcf722c6f27ecb3456cd19b3488c902 Mon Sep 17 00:00:00 2001
From: Akash Mehrotra <mehrotra.akash@gmail.com>
Date: Mon, 15 Aug 2011 14:12:41 +0530
Subject: [PATCH 12/13] LUA: EQ Preset setter

---
 modules/lua/libs/equalizer.c            |   42 ++++++++++++++++++++++++++++++-
 share/lua/http/requests/README.txt      |    3 ++
 share/lua/intf/modules/httprequests.lua |    2 +
 3 files changed, 46 insertions(+), 1 deletions(-)

diff --git a/modules/lua/libs/equalizer.c b/modules/lua/libs/equalizer.c
index ffd492b..0f62412 100644
--- a/modules/lua/libs/equalizer.c
+++ b/modules/lua/libs/equalizer.c
@@ -239,6 +239,45 @@ static int vlclua_equalizer_set( lua_State *L )
     return 1;
 }
 
+/*****************************************************************************
+* Set the preset specified by preset id
+*****************************************************************************/
+static int vlclua_equalizer_setpreset( lua_State *L )
+{
+    int presetid = luaL_checknumber( L, 1 );
+    if( presetid >= NB_PRESETS || presetid < 0 )
+        return 0;
+    input_thread_t *p_input = vlclua_get_input_internal( L );
+    if( p_input )
+    {
+        audio_output_t *p_aout = input_GetAout( p_input );
+        vlc_object_release( p_input );
+        if ( !p_aout )
+        {
+            return 0;
+        }
+        char *psz_af = var_GetNonEmptyString( p_aout, "audio-filter" );
+        if ( !psz_af || strstr ( psz_af, "equalizer" ) == NULL )
+        {
+            vlc_object_release( p_aout );
+            return 0;
+        }
+        char *newstr;
+        asprintf( &newstr , "%6.1f" , eqz_preset_10b[presetid].f_amp[0] );
+        for ( int i = 1 ; i < 10 ; i++ )
+        {
+            asprintf( &newstr, "%s%6.1f",newstr ,eqz_preset_10b[presetid].f_amp[i]);
+        }
+        var_SetString( p_aout, "equalizer-bands",newstr );
+        var_SetFloat( p_aout, "equalizer-preamp", eqz_preset_10b[presetid].f_preamp );
+        var_SetString( p_aout , "equalizer-preset" , preset_list[presetid] );
+        vlc_object_release( p_aout );
+        free( newstr );
+        return 1;
+    }
+    return 0;
+}
+ 
 /****************************************************************************
 * Enable/disable Equalizer
 *****************************************************************************/
@@ -272,7 +311,8 @@ static const luaL_Reg vlclua_equalizer_reg[] = {
     { "equalizerget", vlclua_equalizer_get },
     { "equalizerset", vlclua_equalizer_set },
     { "enable", vlclua_equalizer_enable },
-    {"presets",vlclua_equalizer_get_presets },
+    { "presets",vlclua_equalizer_get_presets },
+    { "setpreset", vlclua_equalizer_setpreset },
     { NULL, NULL }
 };
 
diff --git a/share/lua/http/requests/README.txt b/share/lua/http/requests/README.txt
index 68581b8..d6daf4c 100644
--- a/share/lua/http/requests/README.txt
+++ b/share/lua/http/requests/README.txt
@@ -125,6 +125,9 @@ status.xml or status.json
  0 --  disables the equalizer
  1 --  enables the equalizer
 
+>command=setpreset&val=<presetid>
+ set the equalizer preset as per the id specified
+
 <Displays the equalizer band gains.
 Band 0: 60 Hz, 1: 170 Hz, 2: 310 Hz, 3: 600 Hz, 4: 1 kHz,
 5: 3 kHz, 6: 6 kHz, 7: 12 kHz , 8: 14 kHz , 9: 16 kHz
diff --git a/share/lua/intf/modules/httprequests.lua b/share/lua/intf/modules/httprequests.lua
index f7bc055..78be87d 100644
--- a/share/lua/intf/modules/httprequests.lua
+++ b/share/lua/intf/modules/httprequests.lua
@@ -170,6 +170,8 @@ processcommands = function ()
 	  vlc.equalizer.equalizerset(band,val)
 	elseif command == "enableeq" then
 	  if val == '0' then vlc.equalizer.enable(false) else vlc.equalizer.enable(true) end
+	elseif command == "setpreset" then 
+	  vlc.equalizer.setpreset(val)
 	end
 
 	local input = nil
-- 
1.7.4.1

